'' =================================================================================================
''
''   File....... jm_xbee_packet_viewer.spin
''   Purpose.... Display packets recived via XBee coms
''   Author..... Jon "JonnyMac" McPhalen
''               Copyright (c) 2016 Jon McPhalen
''               -- see below for terms of use
''   E-mail..... jon@jonmcphalen.com
''   Started.... 
''   Updated.... 22 SEP 2017
''
'' =================================================================================================

{
  Jon's XBee setup using XCTU

  -- start with default configuration
  -- change baud (BD) to 57K
  -- change API enabled (AP) to 1 (no escapes)
  -- change DIO7 (D7) to disabled
  -- change DIO5 (D5) to disabled 
}


con { timing }

  _clkmode = xtal1 + pll16x
  _xinfreq = 5_000_000                                          ' use 5MHz crystal
                                                                 
  CLK_FREQ = _xinfreq * (_clkmode >> 6)                         ' system freq as a constant
  MS_001   = CLK_FREQ / 1_000                                   ' ticks in 1ms
  US_001   = CLK_FREQ / 1_000_000                               ' ticks in 1us

  TRM_BAUD = 115_200                                            ' baud rate for terminal
  XB_BAUD  = xbee#BR_57K6                                       ' corrected xbee baud

                                                                  
con { pab io pins }                                               
                                                                  
  RX1     = 31                                                  ' programming / terminal
  TX1     = 30                                      
                                                    
  SDA1    = 29                                                  ' eeprom / i2c
  SCL1    = 28                                                   
                                                                 
  AUD_RT  = 27                                                  ' audio (d/a) outputs
  AUD_LF  = 26                                                   
                                                                 
  LED_27  = 27                                                  ' leds (on audio outputs)
  LED_26  = 26                                                   
                                                                 
  SD_CS   = 25                                                  ' usd card
  SD_DI   = 24                                                   
  SD_CLK  = 23                                                   
  SD_DO   = 22                                                   
                                                                 
  ADC_CS  = 21                                                  ' adc input
  ADC_CLK = 20                                                   
  ADC_DO  = 19                                                   
  ADC_DI  = 18                                                   
                                                                 
  SVO_6   = 17                                                  ' servo headers
  SVO_5   = 16                                                   
  SVO_4   = 15                                                   
  SVO_3   = 14                                                   
  SVO_2   = 13                                                   
  SVO_1   = 12


con { app io }

  RX2     =  7                                                  ' xbee
  TX2     =  6    


con
                                                
  MY_ID = $5200                                                 ' $52 = "R" (for remote)

  
obj                                                              
                                                                 
' main                                                          ' * master spin cog
  time : "jm_time_80"                                           '   delays/timing
  io   : "jm_io"                                                '   basic io
  xbee : "jm_xbee_api1"                                         ' * XBee via API1 interface                                                   
  term : "jm_fullduplexserial"                                  ' * serial for terminal (debugging)
                                                                 
' * uses cog when loaded  


pub main | check, len

  setup

  term.rxflush                                                  ' clear kbd buffer
  term.rx                                                       ' press a key
  term.tx(term#CLS)                                             ' clear the terminal

  term.str(string("Checking for radio.", 13))
  time.pause(25)

  if (xbee.check_radio < 0)                                     ' ensure radio is present
    term.str(string("Error: No radio detected"))
  else
    xbee.set_value(string("MY"), MY_ID, 2)
    time.pause(25)
    xbee.flush                                                  ' clear xbee buffer

  term.str(string("Ready for packets.", 13, 13))
      
  repeat
    len := xbee.get_rx_frame(0)                                 ' check for frame waiting
    if (len > 0)                                                ' if present
      show_rx_frame(len)                                        '  display size & contents
    

pub show_rx_frame(len) : idx

  term.str(string("Bytes = "))
  term.dec(len)
  term.tx(13)

  repeat len 
    if (idx > 0) and ((idx // 8) == 0)                          ' 8 bytes per line
      term.tx(13)
    term.tx("$")
    term.hex(xbee.get_rx(idx), 2)
    term.tx(" ")
    ++idx

  term.txn(13, 2)


pub setup                                                        
                                                                 
  time.start                                                    ' setup for timing/delays
                                                                 
  io.start(0, 0)                                                ' clear pins (this cog) 
                                                        
  term.start(RX1, TX1, %0000, TRM_BAUD)                         ' start serial for terminal *

  xbee.startx(RX2, TX2, XB_BAUD)                                ' start serial for xbee *  


dat { license }

{{

  Terms of Use: MIT License

  Permission is hereby granted, free of charge, to any person obtaining a copy of this
  software and associated documentation files (the "Software"), to deal in the Software
  without restriction, including without limitation the rights to use, copy, modify,
  merge, publish, distribute, sublicense, and/or sell copies of the Software, and to
  permit persons to whom the Software is furnished to do so, subject to the following
  conditions:

  The above copyright notice and this permission notice shall be included in all copies
  or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
  INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
  PARTICULAR PURPOSE AND NON-INFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
  HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
  CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE
  OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

}}